@@ -344,6 +344,15 @@ function whp_ServiceSingleSignOn(array $params) {
         $serverdata = whp_getServerData($params);
         $username = $params['username'];
         
+        // Enhanced debugging for SSO
+        logModuleCall('whp', 'SSO_Debug', array(
+            'username' => $username,
+            'serverdata_keys' => array_keys($serverdata),
+            'hostname' => $serverdata['hostname'] ?? 'not set',
+            'api_key_set' => !empty($serverdata['username']),
+            'api_secret_set' => !empty($serverdata['password'])
+        ), 'Starting SSO process');
+        
         // Generate SSO token
         $apiData = array(
             'username' => $username,
@@ -354,22 +363,40 @@ function whp_ServiceSingleSignOn(array $params) {
         $response = whp_api_call($serverdata, 'POST', 'sso.php?action=generate_token', $apiData);
         
         if ($response['status'] === 'success') {
+            logModuleCall('whp', 'SSO_Success', $apiData, $response['data']['login_url']);
             return array(
                 'success' => true,
                 'redirectTo' => $response['data']['login_url'],
             );
         } else {
+            $errorMsg = $response['message'] ?? 'Unknown API error';
+            
+            // Check for common permission issues
+            if (strpos($errorMsg, 'Insufficient permissions') !== false || strpos($errorMsg, 'Internal server error') !== false) {
+                $errorMsg = 'API key lacks SSO permission. Please enable "SSO Access" permission for the API key used by WHMCS in WHP Server Settings.';
+            }
+            
+            logModuleCall('whp', 'SSO_API_Error', $apiData, 'API Error: ' . $errorMsg);
             return array(
                 'success' => false,
-                'errorMsg' => 'SSO failed: ' . $response['message'],
+                'errorMsg' => 'SSO failed: ' . $errorMsg,
             );
         }
         
     } catch (Exception $e) {
-        logModuleCall('whp', __FUNCTION__, $params, $e->getMessage());
+        $errorMsg = $e->getMessage();
+        
+        // Provide helpful error messages for common issues
+        if (strpos($errorMsg, 'HTTP Error: 500') !== false) {
+            $errorMsg = 'Internal server error. This is likely due to missing SSO permission. Please enable "SSO Access" permission for the API key in WHP Server Settings.';
+        } elseif (strpos($errorMsg, 'HTTP Error: 403') !== false) {
+            $errorMsg = 'Access denied. Please enable "SSO Access" permission for the API key in WHP Server Settings.';
+        }
+        
+        logModuleCall('whp', 'SSO_Exception', $params, 'Exception: ' . $e->getMessage());
         return array(
             'success' => false,
-            'errorMsg' => 'SSO error: ' . $e->getMessage(),
+            'errorMsg' => 'SSO error: ' . $errorMsg,
         );
     }
 }
@@ -443,34 +470,30 @@ function whp_view_usage(array $params) {
             $userInfo = $response['data'];
             $usage = $userInfo['usage'] ?? [];
             
-            $output = '<h4>Current Usage Statistics</h4>';
-            $output .= '<table class="table table-striped">';
+            $output = "Current Usage Statistics:\n\n";
             
             if (isset($usage['disk_used_mb'])) {
                 $diskUsed = intval($usage['disk_used_mb']);
                 $diskLimit = intval($userInfo['resources']['disk_mb'] ?? 0);
                 $diskPercent = $diskLimit > 0 ? ($diskUsed / $diskLimit) * 100 : 0;
                 
-                $output .= '<tr><td><strong>Disk Usage:</strong></td>';
-                $output .= '<td>' . $diskUsed . ' MB / ' . $diskLimit . ' MB (' . number_format($diskPercent, 1) . '%)</td></tr>';
+                $output .= "Disk Usage: " . $diskUsed . " MB / " . $diskLimit . " MB (" . number_format($diskPercent, 1) . "%)\n";
             }
             
             if (isset($usage['last_updated'])) {
-                $output .= '<tr><td><strong>Last Updated:</strong></td>';
-                $output .= '<td>' . htmlspecialchars($usage['last_updated']) . '</td></tr>';
+                $output .= "Last Updated: " . $usage['last_updated'] . "\n";
             }
             
             // Add resource limits
             if (isset($userInfo['resources'])) {
                 $resources = $userInfo['resources'];
-                $output .= '<tr><td colspan="2"><hr><strong>Resource Limits:</strong></td></tr>';
-                $output .= '<tr><td>CPU Cores:</td><td>' . ($resources['cpu_cores'] ?? 'N/A') . '</td></tr>';
-                $output .= '<tr><td>Memory:</td><td>' . ($resources['memory_mb'] ?? 'N/A') . ' MB</td></tr>';
-                $output .= '<tr><td>Email Accounts:</td><td>' . ($resources['email_accounts'] ?? 'N/A') . '</td></tr>';
-                $output .= '<tr><td>Email Storage:</td><td>' . ($resources['email_storage_mb'] ?? 'N/A') . ' MB</td></tr>';
+                $output .= "\nResource Limits:\n";
+                $output .= "- CPU Cores: " . ($resources['cpu_cores'] ?? 'N/A') . "\n";
+                $output .= "- Memory: " . ($resources['memory_mb'] ?? 'N/A') . " MB\n";
+                $output .= "- Email Accounts: " . ($resources['email_accounts'] ?? 'N/A') . "\n";
+                $output .= "- Email Storage: " . ($resources['email_storage_mb'] ?? 'N/A') . " MB\n";
             }
             
-            $output .= '</table>';
             return $output;
         } else {
             return 'Failed to retrieve usage statistics: ' . $response['message'];
